Learn R Programming

scINSIGHT (version 0.1.5)

run_scINSIGHT: Perform scINSIGHT on normalized datasets

Description

Perform INterpreting single cell gene expresSIon bioloGically Heterogeneous daTa (scINSIGHT) to return factorized \(W_{\ell1}\), \(W_{\ell2}\), \(H\) and \(V\) matrices.

This factorization produces a \(W_{\ell1}\) matrix (cells by \(K_j\)), a \(W_{\ell2}\) matrix (cells by \(K\)), a shared \(V\) matrix (\(K\) by genes) for each sample, and a \(H\) (\(K_j\) by genes) matrix for each condition. \(W_{\ell2}\) are the expression matrices of \(K\) common gene modules for all samples, \(V\) is the membership matrix of \(K\) common gene modules, and it's shared by all samples. \(W_{\ell1}\) are the expression matrices of \(K_j\) condition-specific gene modules for all samples, and \(H\) are the membership matrices of \(K_j\) condition-specific gene modules for all conditions.

Usage

run_scINSIGHT(
  object,
  K = seq(5, 15, 2),
  K_j = 2,
  LDA = c(0.001, 0.01, 0.1, 1, 10),
  thre.niter = 500,
  thre.delta = 0.01,
  num.cores = 1,
  B = 5,
  out.dir = NULL,
  method = "increase"
)

Value

scINSIGHT object with \(W_1\), \(W_2\), \(H\), \(V\) and parameters slots set.

Arguments

object

scINSIGHT object.

K

Number of common gene modules. (default c(5, 7, 9, 11, 13, 15))

K_j

Number of dataset-specific gene modules. (default 2)

LDA

Regularization parameters. (default c(0.001, 0.01, 0.1, 1, 10))

thre.niter

Maximum number of block coordinate descent iterations to perform. (default 500)

thre.delta

Stop iteration when the reduction of objective function is less than the threshold. (default 0.01)

num.cores

Number of cores used for optimizing factorizations in parallel (default 1).

B

Number of repeats with random seed from 1 to B. (default 5)

out.dir

Output directory of scINSIGHT results. (default NULL)

method

Method of updating the factorization (default "increase"). If provide multiple \(K\), user can choose method between "increase" and "decrease".

For "increase", the algorithm will first perform factorization with the least \(K=K_1\). Then initialize \(K_2-K_1\) facotrs, where \(K_2\) is the \(K\) sightly larger than \(K_1\), and perform facotrization with these new facotrs. Continue this process until the largest \(K\).

For "increase", the algorithm will first perform factorization with the largest \(K=K_1\). Then choose \(K_2\) facotrs, where \(K_2\) is the \(K\) sightly less than \(K_1\), and perform facotrization with these new facotrs. Continue this process until the least \(K\).